@@ -1,3 +1,4 @@
+from tripleodash import clients
 from tripleodash import dash
 
 
@@ -6,7 +7,7 @@ def main():
     UPDATE_INTERVAL = 2
 
     try:
-        dash.Dashboard(UPDATE_INTERVAL).run()
+        dash.Dashboard(clients.ClientManager(), UPDATE_INTERVAL).run()
     except KeyboardInterrupt:
         print("Exited at users request.")
 
