@@ -2,14 +2,17 @@ from __future__ import print_function
 
 import logging
 import os
+import sys
 
 import cachetools
 from glanceclient.v2.client import Client as GlanceClient
 from heatclient.v1.client import Client as HeatClient
 import ironic_inspector_client
 from ironicclient.v1.client import Client as IronicClient
+from keystoneauth1.exceptions import auth
 from keystoneauth1.exceptions import catalog
 from keystoneclient.v2_0 import client as ksclient
+from novaclient import client as nova_client
 from swiftclient import client as swift_client
 
 LOG = logging.getLogger(__name__)
@@ -38,16 +41,37 @@ class ClientManager(object):
         if 'keystone' in self._cache:
             return self._cache['keystone']
 
-        self._cache['keystone'] = ksclient.Client(
-            username=os.environ.get('OS_USERNAME'),
-            tenant_name=os.environ.get('OS_TENANT_NAME'),
-            password=os.environ.get('OS_PASSWORD'),
-            auth_url=os.environ.get('OS_AUTH_URL'),
-            auth_version=2,
-            insecure=True
-        )
+        try:
+            self._cache['keystone'] = ksclient.Client(
+                username=os.environ.get('OS_USERNAME'),
+                tenant_name=os.environ.get('OS_TENANT_NAME'),
+                password=os.environ.get('OS_PASSWORD'),
+                auth_url=os.environ.get('OS_AUTH_URL'),
+                auth_version=2,
+                insecure=True
+            )
+        except auth.AuthorizationFailure:
+            print("Failed to authenticate with keystone. Check that the "
+                  "OS_USERNAME, OS_PASSWORD, OS_TENANT_NAME and OS_AUTH_URL "
+                  "environment variables are set.", file=sys.stderr)
+            sys.exit()
         return self._cache['keystone']
 
+    @property
+    def nova(self):
+
+        if 'nova' in self._cache:
+            return self._cache['nova']
+
+        self._cache['nova'] = nova_client.Client(
+            2,
+            os.environ.get('OS_USERNAME'),
+            os.environ.get('OS_PASSWORD'),
+            os.environ.get('OS_TENANT_NAME'),
+            os.environ.get('OS_AUTH_URL')
+        )
+        return self._cache['nova']
+
     @property
     def glance(self):
 
@@ -110,10 +134,14 @@ class ClientManager(object):
             return self._cache['inspector']
 
         keystone = self.keystone
-        endpoint = self._get_endpoint(
-            service_type='baremetal-introspection',
-            endpoint_type='publicURL'
-        )
+        try:
+            endpoint = self._get_endpoint(
+                service_type='baremetal-introspection',
+                endpoint_type='publicURL'
+            )
+        except ServiceNotAvailable:
+            # Ironic inspector will default to trying the localhost.
+            endpoint = None
         self._cache['inspector'] = ironic_inspector_client.ClientV1(
             auth_token=keystone.auth_token,
             inspector_url=endpoint)
